@@ -51,6 +51,13 @@ def get_attrname_by_colname(instance, name):
             return attr
 
 
+def get_relationship(table):
+    if not table:
+        return None
+    relations = sqlalchemy.inspect(table).relationships
+    return [rel for rel in relations]
+
+
 def set_instance_name(instance, cols):
     """ It gives you opportunity to get instance attr by column name
         Like this: row.__getattribute__(col.instance_name)
@@ -138,12 +145,15 @@ def store_file(request, key, path):
     # WARNING: this example does not deal with the fact that IE sends an
     # absolute file *path* as the filename.  This example is naive; it
     # trusts user input.
-    filename = request[key][0].filename
+    obj = request[key]
+    if isinstance(obj, (list, tuple)):
+        obj = obj[0]
+    filename = obj.filename
 
     # ``input_file`` contains the actual file data which needs to be
     # stored somewhere.
 
-    input_file = request[key][0].file
+    input_file = obj.file
 
     # Using the filename like this without cleaning it is very
     # insecure so please keep that in mind when writing your own
@@ -157,7 +167,10 @@ def store_file(request, key, path):
         data = input_file.read(2 << 16)
         if not data:
             break
-        output_file.write(bytearray(data, 'UTF-8'))
+        try:
+            output_file.write(bytearray(data, 'utf-8'))
+        except UnicodeDecodeError:  # pragma: no cover
+            output_file.write(bytearray(data))  # pragma: no cover
     output_file.close()
 
 
